@@ -132,9 +132,13 @@ class TestBibtexParsing2(unittest.TestCase):
     def testBibtexEncodedChars(self):
         source = open(setup.BIBTEX_TEST_BIB3, 'r').read()
         results = self.parser.getEntries(source)
+        self.assertEqual(len(results), 2)
         r = results[0]
         self.assertEqual(r['title'], unicode('Der Frst', 'iso-8859-15').encode('utf-8'))
         self.assertEqual(r['publisher'], unicode('Alfred Krner Verlag', 'iso-8859-15').encode('utf-8'))
+        r = results[1]
+        self.assertEqual(r['address'], unicode('Gttingen', 'iso-8859-15').encode('utf-8'))
+        
 
 
 def test_suite():
